@@ -1,11 +1,7 @@
-package
-  Count;
+package Count ;
  
 use Filter::Util::Call ;
  
-use strict ;
-use warnings ;
-
 sub filter
 {
     my ($self) = @_ ;
